FlutterTelinkBlePlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • FlutterTelinkBlePlatform
Implementers

Constructors

FlutterTelinkBlePlatform()
Constructs a FlutterTelinkBlePlatform.

Properties

connectionStateStream → Stream<MeshConnectionStateEvent>
no setter
hashCode → int
The hash code for this object.
no setterinherited
otaProgressStream → Stream<OTAProgress>
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addDeviceToGroup(int deviceAddress, int groupAddress) → Future<void>
connectToMesh() → Future<bool>
disconnectFromMesh() → Future<void>
dispose() → Future<void>
getPlatformVersion() → Future<String?>
initialize(TelinkMeshConfig config) → Future<bool>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
provisionDevice(DeviceProvisionConfig config) → Future<ProvisionResult>
removeDeviceFromGroup(int deviceAddress, int groupAddress) → Future<void>
scanForDevices() → Stream<UnprovisionedDevice>
sendColorCommand(int address, Color color) → Future<void>
sendLevelCommand(int address, int level) → Future<void>
sendOnOffCommand(int address, bool isOn) → Future<void>
startOTA(int deviceAddress, Uint8List firmwareData) → Future<void>
stopScan() → Future<void>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance ↔ FlutterTelinkBlePlatform
The default instance of FlutterTelinkBlePlatform to use.
getter/setter pair