OTAProgress class

Progress information for an OTA update operation

Constructors

OTAProgress({required int deviceAddress, required OTAState state, int progressPercent = 0, int bytesTransferred = 0, int totalBytes = 0, String? error, int? estimatedSecondsRemaining})
const
OTAProgress.fromMap(Map<String, dynamic> map)
Create from map received from platform channel
factory

Properties

bytesTransferred → int
Number of bytes transferred
final
deviceAddress → int
Target device address
final
error → String?
Error message if state is failed
final
estimatedSecondsRemaining → int?
Estimated time remaining in seconds
final
hashCode → int
The hash code for this object.
no setterinherited
progressPercent → int
Progress percentage (0-100)
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state → OTAState
Current state of the OTA update
final
totalBytes → int
Total number of bytes to transfer
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
Convert to map for platform channel communication
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited